@@ -16,7 +16,7 @@ has [qw(backlog max_clients silent)];
 has inactivity_timeout => sub { $ENV{MOJO_INACTIVITY_TIMEOUT} // 30 };
 has ioloop             => sub { Mojo::IOLoop->singleton };
 has keep_alive_timeout => sub { $ENV{MOJO_KEEP_ALIVE_TIMEOUT} // 5 };
-has listen             => sub { [split ',', $ENV{MOJO_LISTEN} || 'http://*:3000'] };
+has listen             => sub { [split /,/, $ENV{MOJO_LISTEN} || 'http://*:3000'] };
 has max_requests       => 100;
 
 sub DESTROY {
